Index: kernel/generic/src/ipc/sysipc.c
===================================================================
--- kernel/generic/src/ipc/sysipc.c	(revision 7c5bcc0ed45d9e1884bc1d0446ed5b150f1cb810)
+++ kernel/generic/src/ipc/sysipc.c	(revision 0c09f2b5b069871c49c79e41106502db160094db)
@@ -349,10 +349,12 @@
 /** Make a fast call over IPC, wait for reply and return to user.
  *
  * This function can handle only one argument of payload, but is faster than
  * the generic function (i.e. sys_ipc_call_sync()).
  *
  * @param phoneid	Phone handle for the call.
  * @param method	Method of the call.
  * @param arg1		Service-defined payload argument.
+ * @param arg2		Service-defined payload argument.
+ * @param arg3		Service-defined payload argument.
  * @param data		Address of userspace structure where the reply call will
  *			be stored.
@@ -362,5 +364,5 @@
  */
 unative_t sys_ipc_call_sync_fast(unative_t phoneid, unative_t method,
-    unative_t arg1, ipc_data_t *data)
+    unative_t arg1, unative_t arg2, unative_t arg3, ipc_data_t *data)
 {
 	call_t call;
@@ -373,4 +375,6 @@
 	IPC_SET_METHOD(call.data, method);
 	IPC_SET_ARG1(call.data, arg1);
+	IPC_SET_ARG2(call.data, arg2);
+	IPC_SET_ARG3(call.data, arg3);
 
 	if (!(res = request_preprocess(&call))) {
@@ -394,5 +398,5 @@
  * @return		Zero on success or an error code.
  */
-unative_t sys_ipc_call_sync(unative_t phoneid, ipc_data_t *question,
+unative_t sys_ipc_call_sync_slow(unative_t phoneid, ipc_data_t *question,
     ipc_data_t *reply)
 {
@@ -349,10 +349,12 @@
 /** Make a fast call over IPC, wait for reply and return to user.
  *
- * This function can handle only one argument of payload, but is faster than
- * the generic function (i.e. sys_ipc_call_sync()).
+ * This function can handle only three arguments of payload, but is faster than
+ * the generic function (i.e. sys_ipc_call_sync_slow()).
  *
  * @param phoneid	Phone handle for the call.
